@@ -6,6 +6,7 @@
  */
 /* NetHack may be freely redistributed.  See license for details. */
 
+/* #define MAKEDEFS_C	1   /* define for Macs */
 #define NEED_VARARGS
 #include	"config.h"
 
@@ -13,6 +14,9 @@
 #undef exit
 extern void exit P((int));
 #endif
+#ifdef AZTEC
+#define abort() exit()
+#endif
  
 /*VARARGS1*/
 boolean panicking;
